==> spip_3.0.18.orig.tar.xz: spip/ecrire/lang/public_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Página inicial',
	'article' => 'Matéria',
	'articles' => 'Matérias',
	'articles_auteur' => 'Matérias deste autor',
	'articles_populaires' => 'Matérias mais populares',
	'articles_rubrique' => 'Matérias desta seção',
	'aucun_article' => 'Não há nenhuma matéria neste endereço',
	'aucun_auteur' => 'Não há nenhum autor neste endereço',
	'aucun_site' => 'Não há nenhum site neste endereço',
	'aucune_breve' => 'Não há nenhuma nota neste endereço',
	'aucune_rubrique' => 'Não há nenhuma seção neste endereço',
	'auteur' => 'Autor',
	'autres' => 'Outros',
	'autres_breves' => 'Outras notas',
	'autres_groupes_mots_clefs' => 'Outros grupos de palavras-chave',
	'autres_sites' => 'Outros sites',

	// B
	'bonjour' => 'Bom dia',

	// C
	'commenter_site' => 'Comentar este site',
	'contact' => 'Contato',
	'copie_document_impossible' => 'Não foi possível copiar o documento',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Última inclusão',
	'dernieres_breves' => 'Últimas notas',
	'derniers_articles' => 'Últimas matérias',
	'derniers_commentaires' => 'Últimos comentários',
	'derniers_messages_forum' => 'Últimas mensagens publicadas nos fóruns',

	// E
	'edition_mode_texte' => 'Edição em modo texto de',
	'en_reponse' => 'Em resposta a:',
	'en_resume' => 'Em resumo',
	'envoyer_message' => 'Enviar uma mensagem',
	'espace_prive' => 'Espaço privado',

	// F
	'formats_acceptes' => 'Formatos aceitos: @formats@.',

	// H
	'hierarchie_site' => 'Hierarquia do site',

	// J
	'jours' => 'dias',

	// L
	'lien_connecter' => 'Conectar-se',

	// M
	'meme_auteur' => 'Do mesmo autor',
	'meme_rubrique' => 'Na mesma seção',
	'memes_auteurs' => 'Dos mesmos autores',
	'message' => 'Mensagem',
	'messages_forum' => 'Mensagens',
	'messages_recents' => 'Mensagens de fórum mais recentes',
	'mots_clef' => 'Palavra-chave',
	'mots_clefs' => 'Palavras-chave',
	'mots_clefs_meme_groupe' => 'Palavras-chave no mesmo grupo',

	// N
	'navigation' => 'Navegação',
	'nom' => 'Nome',
	'nouveautes' => 'As novidades',
	'nouveautes_web' => 'Novidades na web',
	'nouveaux_articles' => 'Novas matérias',
	'nouvelles_breves' => 'Novas notas',

	// P
	'page_precedente' => 'página anterior',
	'page_suivante' => 'página seguinte',
	'par_auteur' => 'por ',
	'participer_site' => 'Você pode participar da vida deste site e propor as suas próprias matérias ao se inscrever abaixo. Você receberá imediatamente um e-mail informando os seus códigos de acesso ao espaço privado do site.',
	'plan_site' => 'Mapa do site',
	'popularite' => 'Popularidade',
	'poster_message' => 'Postar uma mensagem',
	'proposer_site' => 'Você pode propor a inclusão de um site nesta seção:',

	// R
	'repondre_article' => 'Responder a esta matéria',
	'repondre_breve' => 'Responder a esta nota',
	'resultats_recherche' => 'Resultados da busca',
	'retour_debut_forums' => 'Voltar ao início dos fóruns',
	'rubrique' => 'Seção',
	'rubriques' => 'Seções',

	// S
	'signatures_petition' => 'Assinaturas',
	'site_realise_avec_spip' => 'Site realizado com SPIP',
	'sites_web' => 'Websites',
	'sous_rubriques' => 'Subseções',
	'spam' => 'Spam',
	'suite' => 'a seguir',
	'sur_web' => 'Na web',
	'syndiquer_rubrique' => 'Sindicar esta seção',
	'syndiquer_site' => 'Sindicar todo o site',

	// T
	'texte_lettre_information' => 'Esta é a mensagem de informação do site',
	'texte_lettre_information_2' => 'Esta mensagem compila as novidades publicadas desde',

	// V
	'ver_imprimer' => 'Versão para impressão',
	'voir_en_ligne' => 'Ver online',
	'voir_squelette' => 'visualizar o template desta página'
);

?>

==> spip_3.1.0.orig.tar.xz: spip/ecrire/lang/public_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Página inicial',
	'article' => 'Matéria',
	'articles' => 'Matérias',
	'articles_auteur' => 'Matérias deste autor',
	'articles_populaires' => 'Matérias mais populares',
	'articles_rubrique' => 'Matérias desta seção',
	'aucun_article' => 'Não há nenhuma matéria neste endereço',
	'aucun_auteur' => 'Não há nenhum autor neste endereço',
	'aucun_site' => 'Não há nenhum site neste endereço',
	'aucune_breve' => 'Não há nenhuma nota neste endereço',
	'aucune_rubrique' => 'Não há nenhuma seção neste endereço',
	'auteur' => 'Autor',
	'autres' => 'Outros',
	'autres_breves' => 'Outras notas',
	'autres_groupes_mots_clefs' => 'Outros grupos de palavras-chave',
	'autres_sites' => 'Outros sites',

	// B
	'bonjour' => 'Bom dia',

	// C
	'commenter_site' => 'Comentar este site',
	'contact' => 'Contato',
	'copie_document_impossible' => 'Não foi possível copiar o documento',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Última inclusão',
	'dernieres_breves' => 'Últimas notas',
	'derniers_articles' => 'Últimas matérias',
	'derniers_commentaires' => 'Últimos comentários',
	'derniers_messages_forum' => 'Últimas mensagens publicadas nos fóruns',

	// E
	'edition_mode_texte' => 'Edição em modo texto de',
	'en_reponse' => 'Em resposta a:',
	'en_resume' => 'Em resumo',
	'envoyer_message' => 'Enviar uma mensagem',
	'espace_prive' => 'Espaço privado',

	// F
	'formats_acceptes' => 'Formatos aceitos: @formats@.',

	// H
	'hierarchie_site' => 'Hierarquia do site',

	// J
	'jours' => 'dias',

	// L
	'lien_connecter' => 'Conectar-se',

	// M
	'meme_auteur' => 'Do mesmo autor',
	'meme_rubrique' => 'Na mesma seção',
	'memes_auteurs' => 'Dos mesmos autores',
	'message' => 'Mensagem',
	'messages_forum' => 'Mensagens',
	'messages_recents' => 'Mensagens de fórum mais recentes',
	'mots_clef' => 'Palavra-chave',
	'mots_clefs' => 'Palavras-chave',
	'mots_clefs_meme_groupe' => 'Palavras-chave no mesmo grupo',

	// N
	'navigation' => 'Navegação',
	'nom' => 'Nome',
	'nouveautes' => 'As novidades',
	'nouveautes_web' => 'Novidades na web',
	'nouveaux_articles' => 'Novas matérias',
	'nouvelles_breves' => 'Novas notas',

	// P
	'page_precedente' => 'página anterior',
	'page_suivante' => 'página seguinte',
	'par_auteur' => 'por ',
	'participer_site' => 'Você pode participar da vida deste site e propor as suas próprias matérias ao se inscrever abaixo. Você receberá imediatamente um e-mail informando os seus códigos de acesso ao espaço privado do site.',
	'plan_site' => 'Mapa do site',
	'popularite' => 'Popularidade',
	'poster_message' => 'Postar uma mensagem',
	'proposer_site' => 'Você pode propor a inclusão de um site nesta seção:',

	// R
	'repondre_article' => 'Responder a esta matéria',
	'repondre_breve' => 'Responder a esta nota',
	'resultats_recherche' => 'Resultados da busca',
	'retour_debut_forums' => 'Voltar ao início dos fóruns',
	'rubrique' => 'Seção',
	'rubriques' => '@nb@ seções',

	// S
	'signatures_petition' => 'Assinaturas',
	'site_realise_avec_spip' => 'Site realizado com SPIP',
	'sites_web' => 'Websites',
	'sous_rubriques' => 'Subseções',
	'spam' => 'Spam',
	'suite' => 'a seguir',
	'sur_web' => 'Na web',
	'syndiquer_rubrique' => 'Sindicar esta seção',
	'syndiquer_site' => 'Sindicar todo o site',

	// T
	'texte_lettre_information' => 'Esta é a mensagem de informação do site',
	'texte_lettre_information_2' => 'Esta mensagem compila as novidades publicadas desde',

	// V
	'ver_imprimer' => 'Versão para impressão',
	'voir_en_ligne' => 'Ver online',
	'voir_squelette' => 'visualizar o template desta página'
);

?>
